package com.yovinchen.xlcs.activity.service;


import com.yovinchen.xlcs.model.activity.ActivityInfo;
import com.yovinchen.xlcs.model.order.CartInfo;
import com.yovinchen.xlcs.model.product.SkuInfo;
import com.yovinchen.xlcs.vo.activity.ActivityRuleVo;
import com.yovinchen.xlcs.vo.order.CartInfoVo;
import com.yovinchen.xlcs.vo.order.OrderConfirmVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 活动表 服务类
 * </p>
 *
 * @author yovinchen
 * @since 2023-09-17
 */
public interface ActivityInfoService extends IService<ActivityInfo> {


    /**
     * 分页查询
     *
     * @param pageParam
     * @return
     */
    IPage<ActivityInfo> selectPage(Page<ActivityInfo> pageParam);

    /**
     * 获取活动规则id
     *
     * @param activityId
     * @return
     */
    Map<String, Object> findActivityRuleList(Long activityId);

    /**
     * 保存活动规则信息
     *
     * @param activityRuleVo
     */
    void saveActivityRule(ActivityRuleVo activityRuleVo);

    /**
     * 根据关键字获取sku信息列表
     *
     * @param keyword
     * @return
     */
    List<SkuInfo> findSkuInfoByKeyword(String keyword);

    /**
     * 根据skuId列表获取促销信息
     *
     * @param skuIdList
     * @return
     */
    Map<Long, List<String>> findActivity(List<Long> skuIdList);

    /**
     * 根据skuID获取营销数据和优惠卷
     *
     * @param skuId
     * @param userId
     * @return
     */
    Map<String, Object> findActivityAndCoupon(Long skuId, Long userId);

    /**
     * 获取购物车中满足条件优惠券和活动
     *
     * @param cartInfoList
     * @param userId
     * @return
     */
    OrderConfirmVo findCartActivityAndCoupon(List<CartInfo> cartInfoList, Long userId);

    /**
     * 获取购物车对应规则数据
     *
     * @param cartInfoList
     * @return
     */
    List<CartInfoVo> findCartActivityList(List<CartInfo> cartInfoList);
}
