package com.yovinchen.xlcs.order.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yovinchen.xlcs.common.result.Result;
import com.yovinchen.xlcs.model.order.OrderInfo;
import com.yovinchen.xlcs.order.service.OrderInfoService;
import com.yovinchen.xlcs.vo.order.OrderQueryVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * ClassName: OrderInfoAdminController
 * Package: com.yovinchen.xlcs.order.controller
 *
 * @author yovinchen
 * @since 2024/1/30 10:47
 */
@Api(value = "订单管理", tags = "订单管理")
@RestController
@RequestMapping("/admin/order/orderInfo")
public class OrderInfoAdminController {
    @Autowired
    private OrderInfoService orderInfoService;

    @ApiOperation(value = "获取订单分页列表")
    @GetMapping("{page}/{limit}")
    public Result<IPage<OrderInfo>> index(@ApiParam(name = "page", value = "当前页码", required = true) @PathVariable Long page, @ApiParam(name = "limit", value = "每页记录数", required = true) @PathVariable Long limit, @ApiParam(name = "OrderQueryVo", value = "查询对象", required = false) OrderQueryVo orderQueryVo) {
        try {
            Page<OrderInfo> pageParam = new Page<>(page, limit);
            IPage<OrderInfo> pageModel = orderInfoService.selectPage(pageParam, orderQueryVo);
            return Result.ok(pageModel);
        } catch (Exception e) {
            throw new RuntimeException("获取sku分页列表异常", e);
        }
    }

    @ApiOperation("获取订单详情信息")
    @GetMapping("get/{orderId}")
    public Result<OrderInfo> show(@ApiParam(name = "orderNo", value = "订单id", readOnly = true) @PathVariable Long orderId) {
        try {
            OrderInfo orderInfo = orderInfoService.getOrderInfoById(orderId);
            return Result.ok(orderInfo);
        } catch (Exception e) {
            throw new RuntimeException("获取订单详情信息异常", e);
        }
    }


}
